/**
 * Logs the beginning of executing a stored procedure.
 *
 * @param p_routine_name The name of the stored procedure.
 */
create procedure abc_log_sp_begin(in p_routine_name varchar(64))
reads sql data
-- type: hidden
begin
  select concat_ws(' ', 'Start:', p_routine_name ) as `line`;
end
